@@ -218,6 +218,10 @@ In case the service has been recently started please wait 5 minutes for it to be
         try:
             input_data_labels = []
             input_data_items = []
+            input_data_labels.append("backend")
+            input_data_items.append(backend)
+            input_data_labels.append("shots")
+            input_data_items.append(str(shots))
             for input_data_label in input_data.data.keys():
                 input_data_labels.append(input_data_label)
                 input_data_items.append(input_data.data[input_data_label])
@@ -235,7 +239,7 @@ In case the service has been recently started please wait 5 minutes for it to be
             if status_code == 201:
                 return WorkflowJob(result["id"])
             else:
-                print(f"Workflow job submission has failed: {result.lower()}.")
+                print(f"Workflow job submission has failed: {result}.")
                 return WorkflowJob(None)
         except Exception as ex:
             print(str(ex))
